@@ -149,6 +149,8 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
                                              value, ck_type)
           self.__config.set_value(config_key, value)
       self.__config.save()
+      for iface in self.__interfaces:
+        iface.update()
     settings_dialog.destroy()
 
   def process_sai(self, iname, image='', add=True):
