@@ -211,6 +211,9 @@ class AbstractInterface():
     self.__processing = False
     self.stop_animation()
 
+  def update(self):
+    self.__update_ui()
+
   def __update_ui(self):
     windex = self.state['value']
     image = self.state['images'][windex]
@@ -331,8 +334,8 @@ class AbstractInterface():
     self.__button.get_image().set_from_pixbuf(self.__smi_cacher.get(key))
 
   def __set_sai(self, key):
-    if any(self.state['show']) and self.get_config_value('show-sa-icon'):
-      if self.state['show'][self.state['value']]:
+    if any(self.state['show']):
+      if self.state['show'][self.state['value']] and self.get_config_value('show-sa-icon'):
         self.__set_status_area_icon(self.__name, key)
       else: 
         self.__set_status_area_icon(self.__name, None, False)
